import { AssignOptions, TypeData } from '../types';
/**
 * @description
 * A custom hook that makes a request to assign an experiment via the API for the SDK entity. Must be used in
 * a child component of the {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or
 * else it throws an error.
 * It wraps {@link ExperimentSDK.assign} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior.
 *
 * CAN make a POST API call.
 * Does NOT return assignment information--users should use 'useAssignment' hook for that.
 *
 * Intended usage:
 * Assign the SDK entity for an experiment in a React application.
 * Can only take 1 experiment name per call. (If you are looking to pass multiple experiment names in 1 call,
 * perhaps that means this experiment allocation point should be a reusable allocation point.)
 *
 * @param experimentName Required. Please see {@link ExperimentSDK.assign} for more details.
 * @param {AssignOptions} options Optional. Please see {@link ExperimentSDK.assign} for more details.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useAssign } from '@mongodb-js/mdb-experiment-js/react';
 * import { Types } from 'SomeParentComponent'
 *
 * return default function ProviderChildComponent() {
 *  useAssign(Types.ExperimentNames.EXP_ONE, {
 *    team: 'Team1'
 *  });
 *
 *  return (
 *    <>
 *      ...
 *    </>
 *  );
 * }
 */
export default function useAssign<T extends TypeData>(experimentName: T['experimentNames'], options?: AssignOptions): void;
//# sourceMappingURL=useAssign.d.ts.map