import { AssignByPointsOptions, TypeData } from '../types';
/**
 * @description
 * A custom hook that makes a request to assign all experiments associated with the given allocation points via the API
 * for the SDK entity.
 *
 * Must be used in a child component of the {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or
 * else it throws an error.
 * It wraps {@link ExperimentSDK.assignByPoints} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior.
 *
 * CAN make a POST API call.
 *
 * Does NOT return assignment information--users should use the useAssignment hook for that.
 *
 * Intended usage:
 * Assign entities for experiments configured to use reusable allocation points in a React application.
 * Can take multiple points in 1 call.
 *
 * @param allocationPoints - Required. An array of allocation point name strings.
 * Please see {@link ExperimentSDK.assignByPoints} for more details.
 * @param {AssignByPointsOptions} options - Optional. Object with additional optional props, such as a "team" override
 * for logging purposes and a timeoutMs prop to define the API timeout.
 * Please see {@link ExperimentSDK.assignByPoints} for more details.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useAssignByPoints } from '@mongodb-js/mdb-experiment-js/react';
 * import { Types } from 'SomeParentComponent'
 *
 * return default function ProviderChildComponent() {
 *  const allocationPointsArray: Array<AllocationPointNames> = [
 *   AllocationPointNames.CLUSTER_CARD_PAGE,
 *   AllocationPointNames.REGISTRATION_SUCCESS_PAGE,
 * ];
 *
 *  const options: AssignByPointsOptions = {
 *   team: 'Test Team 1',
 *  };
 *
 *  useAssignByPoints(allocationPointsArray, options);
 *
 *  return (
 *    <>
 *      ...
 *    </>
 *  );
 * }
 */
export default function useAssignByPoints<T extends TypeData>(allocationPoints: Array<T['allocationPointNames']>, options?: AssignByPointsOptions): void;
//# sourceMappingURL=useAssignByPoints.d.ts.map