import { GetAssignmentOptions, SDKAssignment, TypeData } from '../types';
/**
 * @description
 * A custom hook that retrieves an entity's assignment in a given experiment. Must be used in
 * a child component of the {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or
 * else it throws an error.
 * It wraps {@link ExperimentSDK.getAssignment} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior.
 *
 * Intended usage:
 * To get an entity's experiment assignment information in a React application.
 *
 * @param experimentName Required. Please see {@link ExperimentSDK.getAssignment} for more details.
 * @param trackIsInSample Required. Please see {@link ExperimentSDK.getAssignment} for more details.
 * @param options Optional. Please see {@link ExperimentSDK.getAssignment} for more details.
 * @return An {@link SDKAssignment} object or null. Even if an SDKAssignment object comes back, the entity
 * may not be in the experiment--check {@link SDKAssignment.assignmentData.isInSample} to be sure.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useAssignment } from '@mongodb-js/mdb-experiment-js/react';
 * import { Types } from 'SomeParentComponent'
 *
 * return default function ProviderChildComponent() {
 *  const assignment = useAssignment(Types.ExperimentNames.EXP_ONE, false);
 *
 *  return (
 *    <>
 *      assignment variant: {assignment?.assignmentData.variant}
 *    </>
 *  );
 * }
 */
export default function useAssignment<T extends TypeData>(experimentName: T['experimentNames'], trackIsInSample: boolean, options?: GetAssignmentOptions<T>): SDKAssignment<T['experimentNames'], T['experimentVariantNames']> | null;
//# sourceMappingURL=useAssignment.d.ts.map