import { TypeData } from '../types';
import { UseTrackIsInSampleConfig } from './types';
/**
 * @description
 * A custom hook that sends an "Experiment Viewed" event with the client's tracker (if any). Sends through default
 * props ({@link ExperimentViewedBaseEvent}) and any custom props defined. Must be used in a child component of the
 * {@link ExperimentSDKProvider} with a non-null sdkInstance in Context, or else it throws an error.
 * It wraps {@link ExperimentSDK.trackIsInSample} in a useEffect hook--please see that function's
 * JSDocs for further details about behavior.
 *
 * Intended usage:
 * To send an "Experiment Viewed" event in a React application.
 *
 * @param {ExperimentName} config.experimentName - Required. An experiment string name.
 * @param {boolean} config.shouldFireEvent - Optional. Indicates whether the event should fire. Useful if experiment
 *  allocation relies on a conditional e.g. 'page has config setting A'.
 * @param {Object} config.customProperties - Optional. User of this function can pass in an optional
 * customProps object if they want the Experiment Viewed event to have custom properties in addition
 * to the default experiment props ({@link ExperimentViewedBaseEvent})
 * @param {string} config.team - Optional. Team string name for logging.
 *
 * @example
 * // SomeParentComponent.tsx component file
 * import ExperimentSDKClient, { types } from '@mongodb-js/mdb-experiment-js';
 * import { ExperimentSDKProvider } from '@mongodb-js/mdb-experiment-js/react';
 *
 * // see the ExperimentSDKClient JSDoc example for full details of "Types" and "options"
 * const sdk = ExperimentSDKClient.create<Types>(options);
 *
 * const sdkProvider = (
 *  <ExperimentSDKProvider
 *    sdkInstance={sdk}
 *  >
 *    <ProviderChildComponent />
 *  </ExperimentSDKProvider>
 * );
 *
 * // ProviderChildComponent.tsx component file
 * import { useTrackIsInSample } from '@mongodb-js/mdb-experiment-js/react';
 * import { Types } from 'SomeParentComponent'
 *
 * return default function ProviderChildComponent() {
 *
 *   useTrackIsInSample({
 *     experimentName: Types.ExperimentNames.EXP_ONE,
 *     shouldFireEvent: // some condition
 *     customProperties: {
 *         customProp1: 'prop1',
 *         customProp2: 'prop2'
 *     },
 *     team: 'Team1',
 *   });
 *
 *   return (
 *     <>
 *       ...
 *     </>
 *   );
 * }
 */
export default function useIsInTrackSample<T extends TypeData>({ experimentName, shouldFireEvent, customProperties, team, }: UseTrackIsInSampleConfig<T['experimentViewedProps']>): void;
//# sourceMappingURL=useTrackIsInSample.d.ts.map